
pyros-common
============

.. image:: https://travis-ci.org/pyros-dev/pyros-config.svg?branch=master
    :target: https://travis-ci.org/pyros-dev/pyros-config
    :alt: Travis

.. image:: https://pyup.io/repos/github/pyros-dev/pyros-common/shield.svg
     :target: https://pyup.io/repos/github/pyros-dev/pyros-common/
     :alt: Updates

.. image:: https://pyup.io/repos/github/pyros-dev/pyros-common/python-3-shield.svg
     :target: https://pyup.io/repos/github/pyros-dev/pyros-common/
     :alt: Python 3

Pyros packages shared by all extensions.
